MessageStatusHandler

Struct MessageStatusHandler 

pub struct MessageStatusHandler { /* private fields */ }
Event handler for updating message status in the database

This handler listens for MessageAccepted and MessageRejected events and updates the corresponding message status in the database.

Implementations

Source

impl MessageStatusHandler

pub fn new(storage: Arc<Storage>) -> Self

Create a new message status handler