Module trust_ping_handler

Module trust_ping_handler 

Trust Ping Response Event Handler

This module provides an event handler that listens for Trust Ping response events and sends them through the appropriate channels.

Structs

TrustPingResponseHandler
Event handler that processes Trust Ping response events and sends them