Module message

PlainMessage processing and routing for TAP Node

This module provides functionality for processing and routing TAP messages between agents.

Re-exports

pub use processor::DefaultPlainMessageProcessor;
pub use processor::LoggingPlainMessageProcessor;
pub use processor::PlainMessageProcessor;
pub use processor::StateMachineIntegrationProcessor;
pub use processor::ValidationPlainMessageProcessor;
pub use processor_pool::ProcessorPool;
pub use processor_pool::ProcessorPoolConfig;
pub use router::DefaultPlainMessageRouter;
pub use router::IntraNodePlainMessageRouter;
pub use sender::HttpPlainMessageSender;
pub use sender::NodePlainMessageSender;
pub use sender::PlainMessageSender;

Modules

processor
PlainMessage Processor Implementations for TAP Node
processor_pool
Processor pool for concurrent message processing.
router
PlainMessage routing implementation.
sender
PlainMessage sender implementations for TAP Node.

Structs

CompositePlainMessageProcessor
A message processor that applies multiple processors in sequence
CompositePlainMessageRouter
A composite router that tries multiple routers in sequence

Enums

PlainMessageProcessorType
Processor enum to replace trait objects
PlainMessageRouterType
Router enum to replace trait objects

Traits

PlainMessageRouter
Router to determine the destination agent for a message
RouterAsyncExt
Async extension trait for the PlainMessageRouter