Module router

PlainMessage routing implementation.

This module provides message routing capabilities for the TAP Node.

Structs

CompositePlainMessageRouter
Composite message router that can delegate to multiple routers
DefaultPlainMessageRouter
Default implementation of PlainMessageRouter
IntraNodePlainMessageRouter
Intra-node router that handles routing between local agents