Trait MessageSender

pub trait MessageSender:
    Send
    + Sync
    + Debug {
    // Required method
    fn send<'life0, 'async_trait>(
        &'life0 self,
        packed_message: String,
        recipient_dids: Vec<String>,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Message sender trait for sending packed messages to recipients

Required Methods

fn send<'life0, 'async_trait>( &'life0 self, packed_message: String, recipient_dids: Vec<String>, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Send a packed message to one or more recipients

Implementors