pub trait PlainMessageRouter: Send + Sync {
// Required method
fn route_message_impl(&self, message: &PlainMessage) -> Result<String>;
}Expand description
Router to determine the destination agent for a message
Required Methods
Sourcefn route_message_impl(&self, message: &PlainMessage) -> Result<String>
fn route_message_impl(&self, message: &PlainMessage) -> Result<String>
Route a message to determine the target agent DID
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".