pub struct Transition {
pub from_state: TransactionState,
pub to_state: TransactionState,
pub event: FsmEvent,
pub decision: Option<Decision>,
}Expand description
The outcome of applying an event to the FSM.
Fields
from_state: TransactionStateThe state before the transition.
to_state: TransactionStateThe state after the transition.
event: FsmEventThe event that triggered this transition.
decision: Option<Decision>If the new state is a decision point, this describes the decision that must be made by the external system.