pub struct AgentAuthorizationValidator { /* private fields */ }Expand description
Validator that ensures only authorized agents can respond to transactions
This validator checks that messages responding to a transaction (like Authorize, Cancel, Reject) are only accepted from agents that are part of the transaction.
Implementations