pub struct MessageStatusHandler { /* private fields */ }Expand description
Event handler for updating message status in the database
This handler listens for MessageAccepted and MessageRejected events and updates the corresponding message status in the database.
Implementations