PlainMessage processing and routing for TAP Node
This module provides functionality for processing and routing TAP messages between agents.
Re-exports
pub use processor::DefaultPlainMessageProcessor;pub use processor::LoggingPlainMessageProcessor;pub use processor::PlainMessageProcessor;pub use processor::ValidationPlainMessageProcessor;pub use processor_pool::ProcessorPool;pub use processor_pool::ProcessorPoolConfig;pub use router::DefaultPlainMessageRouter;pub use sender::HttpPlainMessageSender;pub use sender::NodePlainMessageSender;pub use sender::PlainMessageSender;
Modules
- processor
- PlainMessage Processor Implementations for TAP Node
- processor_
pool - Processor pool for concurrent message processing.
- router
- PlainMessage routing implementation.
- sender
- PlainMessage sender implementations for TAP Node.
Structs
- Composite
Plain Message Processor - A message processor that applies multiple processors in sequence
- Composite
Plain Message Router - A composite router that tries multiple routers in sequence
Enums
- Plain
Message Processor Type - Processor enum to replace trait objects
- Plain
Message Router Type - Router enum to replace trait objects
Traits
- Plain
Message Router - Router to determine the destination agent for a message
- Router
Async Ext - Async extension trait for the PlainMessageRouter